==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/log_query_definition_group_by.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort

    globals()["LogQueryDefinitionGroupBySort"] = LogQueryDefinitionGroupBySort


class LogQueryDefinitionGroupBy(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "facet": (str,),
            "limit": (int,),
            "sort": (LogQueryDefinitionGroupBySort,),
        }

    attribute_map = {
        "facet": "facet",
        "limit": "limit",
        "sort": "sort",
    }

    read_only_vars = {}

    def __init__(self, facet, *args, **kwargs):
        """
        Defined items in the group.

        :param facet: Facet name.
        :type facet: str

        :param limit: Maximum number of items in the group.
        :type limit: int, optional

        :param sort: Define a sorting method.
        :type sort: LogQueryDefinitionGroupBySort, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.facet = facet

    @classmethod
    def _from_openapi_data(cls, facet, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogQueryDefinitionGroupBy, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.facet = facet
        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/log_query_definition_group_by.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.log_query_definition_group_by_sort import LogQueryDefinitionGroupBySort

    globals()["LogQueryDefinitionGroupBySort"] = LogQueryDefinitionGroupBySort


class LogQueryDefinitionGroupBy(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "facet": (str,),
            "limit": (int,),
            "sort": (LogQueryDefinitionGroupBySort,),
        }

    attribute_map = {
        "facet": "facet",
        "limit": "limit",
        "sort": "sort",
    }

    def __init__(self, facet, *args, **kwargs):
        """
        Defined items in the group.

        :param facet: Facet name.
        :type facet: str

        :param limit: Maximum number of items in the group.
        :type limit: int, optional

        :param sort: Define a sorting method.
        :type sort: LogQueryDefinitionGroupBySort, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.facet = facet

    @classmethod
    def _from_openapi_data(cls, facet, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogQueryDefinitionGroupBy, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.facet = facet
        return self
